@@ -6,21 +6,24 @@ use std::cmp::Ordering;
 use noisy_float::prelude::*;
 use permutohedron::LexicalPermutation;
 
+/// A metric (distance function) in the space of all events
 pub trait Distance {
     fn distance(&self, ev1: &Event, ev2: &Event) -> N64;
 }
 
 const FALLBACK_SIZE: usize = 8;
 
+/// The distance function defined in [arXiv:2109.07851](https://arxiv.org/abs/2109.07851)
+#[derive(Copy, Clone, Eq, PartialEq, Ord, PartialOrd, Hash, Debug, Default)]
 pub struct EuclWithScaledPt {
-    pt_weight: N64
+    pt_weight: N64,
 }
 
 impl Distance for EuclWithScaledPt {
     fn distance(&self, ev1: &Event, ev2: &Event) -> N64 {
         let mut dist = n64(0.);
-        let out1 = &ev1.outgoing_by_pid;
-        let out2 = &ev2.outgoing_by_pid;
+        let out1 = ev1.outgoing();
+        let out2 = ev2.outgoing();
         let mut idx1 = 0;
         let mut idx2 = 0;
         while idx1 < out1.len() && idx2 < out2.len() {
@@ -61,8 +64,12 @@ impl Distance for EuclWithScaledPt {
 }
 
 impl EuclWithScaledPt {
+    /// Distance function with the given parameter τ = `pt_weight`
+    ///
+    /// See [arXiv:2109.07851](https://arxiv.org/abs/2109.07851) for a
+    /// definition of τ
     pub fn new(pt_weight: N64) -> Self {
-        EuclWithScaledPt{pt_weight}
+        EuclWithScaledPt { pt_weight }
     }
 
     fn pt_norm(&self, p: &[FourVector]) -> N64 {
@@ -102,7 +109,11 @@ impl EuclWithScaledPt {
             .sum()
     }
 
-    fn norm_ordered_paired_distance(&self, p1: &[FourVector], p2: &[FourVector]) -> N64 {
+    fn norm_ordered_paired_distance(
+        &self,
+        p1: &[FourVector],
+        p2: &[FourVector],
+    ) -> N64 {
         if p1.len() > p2.len() {
             return self.norm_ordered_paired_distance(p2, p1);
         }
